
'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ecosmos/mint/v1beta1/mint.proto\x12\x13cosmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto"\xb2\x01\n\x06Minter\x12A\n\tinflation\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12e\n\x11annual_provisions\x18\x02 \x01(\tBJ\xf2\xde\x1f\x18yaml:"annual_provisions"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00"\xdf\x03\n\x06Params\x12\x12\n\nmint_denom\x18\x01 \x01(\t\x12m\n\x15inflation_rate_change\x18\x02 \x01(\tBN\xf2\xde\x1f\x1cyaml:"inflation_rate_change"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12]\n\rinflation_max\x18\x03 \x01(\tBF\xf2\xde\x1f\x14yaml:"inflation_max"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12]\n\rinflation_min\x18\x04 \x01(\tBF\xf2\xde\x1f\x14yaml:"inflation_min"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Y\n\x0bgoal_bonded\x18\x05 \x01(\tBD\xf2\xde\x1f\x12yaml:"goal_bonded"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x123\n\x0fblocks_per_year\x18\x06 \x01(\x04B\x1a\xf2\xde\x1f\x16yaml:"blocks_per_year":\x04\x98\xa0\x1f\x00B+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.mint.v1beta1.mint_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/mint/types'
    _MINTER.fields_by_name['inflation']._options = None
    _MINTER.fields_by_name['inflation']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _MINTER.fields_by_name['annual_provisions']._options = None
    _MINTER.fields_by_name['annual_provisions']._serialized_options = b'\xf2\xde\x1f\x18yaml:"annual_provisions"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['inflation_rate_change']._options = None
    _PARAMS.fields_by_name['inflation_rate_change']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"inflation_rate_change"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['inflation_max']._options = None
    _PARAMS.fields_by_name['inflation_max']._serialized_options = b'\xf2\xde\x1f\x14yaml:"inflation_max"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['inflation_min']._options = None
    _PARAMS.fields_by_name['inflation_min']._serialized_options = b'\xf2\xde\x1f\x14yaml:"inflation_min"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['goal_bonded']._options = None
    _PARAMS.fields_by_name['goal_bonded']._serialized_options = b'\xf2\xde\x1f\x12yaml:"goal_bonded"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['blocks_per_year']._options = None
    _PARAMS.fields_by_name['blocks_per_year']._serialized_options = b'\xf2\xde\x1f\x16yaml:"blocks_per_year"'
    _PARAMS._options = None
    _PARAMS._serialized_options = b'\x98\xa0\x1f\x00'
    _MINTER._serialized_start = 78
    _MINTER._serialized_end = 256
    _PARAMS._serialized_start = 259
    _PARAMS._serialized_end = 738




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$sentinel/subscription/v1/quota.proto\x12\x18sentinel.subscription.v1\x1a\x14gogoproto/gogo.proto"\x9d\x01\n\x05Quota\x12\x0f\n\x07address\x18\x01 \x01(\t\x12A\n\tallocated\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12@\n\x08consumed\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00BIZ?github.com/sentinel-official/hub/x/subscription/legacy/v1/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.quota_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z?github.com/sentinel-official/hub/x/subscription/legacy/v1/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _QUOTA.fields_by_name['allocated']._options = None
    _QUOTA.fields_by_name['allocated']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _QUOTA.fields_by_name['consumed']._options = None
    _QUOTA.fields_by_name['consumed']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _QUOTA._serialized_start = 89
    _QUOTA._serialized_end = 246




from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class ListAllInterfacesRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class ListAllInterfacesResponse(_message.Message):
    __slots__ = ['interface_names']
    INTERFACE_NAMES_FIELD_NUMBER: _ClassVar[int]
    interface_names: _containers.RepeatedScalarFieldContainer[str]

    def __init__(self, interface_names: _Optional[_Iterable[str]]=...) -> None:
        ...

class ListImplementationsRequest(_message.Message):
    __slots__ = ['interface_name']
    INTERFACE_NAME_FIELD_NUMBER: _ClassVar[int]
    interface_name: str

    def __init__(self, interface_name: _Optional[str]=...) -> None:
        ...

class ListImplementationsResponse(_message.Message):
    __slots__ = ['implementation_message_names']
    IMPLEMENTATION_MESSAGE_NAMES_FIELD_NUMBER: _ClassVar[int]
    implementation_message_names: _containers.RepeatedScalarFieldContainer[str]

    def __init__(self, implementation_message_names: _Optional[_Iterable[str]]=...) -> None:
        ...




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class EventGrant(_message.Message):
    __slots__ = ['grantee', 'granter', 'msg_type_url']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    granter: str
    msg_type_url: str

    def __init__(self, msg_type_url: _Optional[str]=..., granter: _Optional[str]=..., grantee: _Optional[str]=...) -> None:
        ...

class EventRevoke(_message.Message):
    __slots__ = ['grantee', 'granter', 'msg_type_url']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    granter: str
    msg_type_url: str

    def __init__(self, msg_type_url: _Optional[str]=..., granter: _Optional[str]=..., grantee: _Optional[str]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from sentinel.types.v1 import bandwidth_pb2 as _bandwidth_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Proof(_message.Message):
    __slots__ = ['bandwidth', 'duration', 'id']
    BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    bandwidth: _bandwidth_pb2.Bandwidth
    duration: _duration_pb2.Duration
    id: int

    def __init__(self, id: _Optional[int]=..., bandwidth: _Optional[_Union[(_bandwidth_pb2.Bandwidth, _Mapping)]]=..., duration: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class Metadata(_message.Message):
    __slots__ = ['address', 'controller_connection_id', 'encoding', 'host_connection_id', 'tx_type', 'version']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CONTROLLER_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    ENCODING_FIELD_NUMBER: _ClassVar[int]
    HOST_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    TX_TYPE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    address: str
    controller_connection_id: str
    encoding: str
    host_connection_id: str
    tx_type: str
    version: str

    def __init__(self, version: _Optional[str]=..., controller_connection_id: _Optional[str]=..., host_connection_id: _Optional[str]=..., address: _Optional[str]=..., encoding: _Optional[str]=..., tx_type: _Optional[str]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/slashing/v1beta1/query.proto\x12\x17cosmos.slashing.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a&cosmos/slashing/v1beta1/slashing.proto"\x14\n\x12QueryParamsRequest"L\n\x13QueryParamsResponse\x125\n\x06params\x18\x01 \x01(\x0b2\x1f.cosmos.slashing.v1beta1.ParamsB\x04\xc8\xde\x1f\x00"/\n\x17QuerySigningInfoRequest\x12\x14\n\x0ccons_address\x18\x01 \x01(\t"i\n\x18QuerySigningInfoResponse\x12M\n\x10val_signing_info\x18\x01 \x01(\x0b2-.cosmos.slashing.v1beta1.ValidatorSigningInfoB\x04\xc8\xde\x1f\x00"V\n\x18QuerySigningInfosRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x9b\x01\n\x19QuerySigningInfosResponse\x12A\n\x04info\x18\x01 \x03(\x0b2-.cosmos.slashing.v1beta1.ValidatorSigningInfoB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse2\xf2\x03\n\x05Query\x12\x8c\x01\n\x06Params\x12+.cosmos.slashing.v1beta1.QueryParamsRequest\x1a,.cosmos.slashing.v1beta1.QueryParamsResponse"\'\x82\xd3\xe4\x93\x02!\x12\x1f/cosmos/slashing/v1beta1/params\x12\xb1\x01\n\x0bSigningInfo\x120.cosmos.slashing.v1beta1.QuerySigningInfoRequest\x1a1.cosmos.slashing.v1beta1.QuerySigningInfoResponse"=\x82\xd3\xe4\x93\x027\x125/cosmos/slashing/v1beta1/signing_infos/{cons_address}\x12\xa5\x01\n\x0cSigningInfos\x121.cosmos.slashing.v1beta1.QuerySigningInfosRequest\x1a2.cosmos.slashing.v1beta1.QuerySigningInfosResponse".\x82\xd3\xe4\x93\x02(\x12&/cosmos/slashing/v1beta1/signing_infosB/Z-github.com/cosmos/cosmos-sdk/x/slashing/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSIGNINGINFORESPONSE.fields_by_name['val_signing_info']._options = None
    _QUERYSIGNINGINFORESPONSE.fields_by_name['val_signing_info']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSIGNINGINFOSRESPONSE.fields_by_name['info']._options = None
    _QUERYSIGNINGINFOSRESPONSE.fields_by_name['info']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02!\x12\x1f/cosmos/slashing/v1beta1/params'
    _QUERY.methods_by_name['SigningInfo']._options = None
    _QUERY.methods_by_name['SigningInfo']._serialized_options = b'\x82\xd3\xe4\x93\x027\x125/cosmos/slashing/v1beta1/signing_infos/{cons_address}'
    _QUERY.methods_by_name['SigningInfos']._options = None
    _QUERY.methods_by_name['SigningInfos']._serialized_options = b'\x82\xd3\xe4\x93\x02(\x12&/cosmos/slashing/v1beta1/signing_infos'
    _QUERYPARAMSREQUEST._serialized_start = 200
    _QUERYPARAMSREQUEST._serialized_end = 220
    _QUERYPARAMSRESPONSE._serialized_start = 222
    _QUERYPARAMSRESPONSE._serialized_end = 298
    _QUERYSIGNINGINFOREQUEST._serialized_start = 300
    _QUERYSIGNINGINFOREQUEST._serialized_end = 347
    _QUERYSIGNINGINFORESPONSE._serialized_start = 349
    _QUERYSIGNINGINFORESPONSE._serialized_end = 454
    _QUERYSIGNINGINFOSREQUEST._serialized_start = 456
    _QUERYSIGNINGINFOSREQUEST._serialized_end = 542
    _QUERYSIGNINGINFOSRESPONSE._serialized_start = 545
    _QUERYSIGNINGINFOSRESPONSE._serialized_end = 700
    _QUERY._serialized_start = 703
    _QUERY._serialized_end = 1201




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.mint.v1beta1 import mint_pb2 as _mint_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['minter', 'params']
    MINTER_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    minter: _mint_pb2.Minter
    params: _mint_pb2.Params

    def __init__(self, minter: _Optional[_Union[(_mint_pb2.Minter, _Mapping)]]=..., params: _Optional[_Union[(_mint_pb2.Params, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"cosmos/crypto/secp256r1/keys.proto\x12\x17cosmos.crypto.secp256r1\x1a\x14gogoproto/gogo.proto""\n\x06PubKey\x12\x18\n\x03key\x18\x01 \x01(\x0cB\x0b\xda\xde\x1f\x07ecdsaPK"&\n\x07PrivKey\x12\x1b\n\x06secret\x18\x01 \x01(\x0cB\x0b\xda\xde\x1f\x07ecdsaSKB@Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\xc8\xe3\x1e\x01\xd8\xe1\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.secp256r1.keys_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\xc8\xe3\x1e\x01\xd8\xe1\x1e\x00\xc8\xe1\x1e\x00'
    _PUBKEY.fields_by_name['key']._options = None
    _PUBKEY.fields_by_name['key']._serialized_options = b'\xda\xde\x1f\x07ecdsaPK'
    _PRIVKEY.fields_by_name['secret']._options = None
    _PRIVKEY.fields_by_name['secret']._serialized_options = b'\xda\xde\x1f\x07ecdsaSK'
    _PUBKEY._serialized_start = 85
    _PUBKEY._serialized_end = 119
    _PRIVKEY._serialized_start = 121
    _PRIVKEY._serialized_end = 159




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ecosmos/base/v1beta1/coin.proto\x12\x13cosmos.base.v1beta1\x1a\x14gogoproto/gogo.proto"8\n\x04Coin\x12\r\n\x05denom\x18\x01 \x01(\t\x12\x1b\n\x06amount\x18\x02 \x01(\tB\x0b\xda\xde\x1f\x03Int\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01";\n\x07DecCoin\x12\r\n\x05denom\x18\x01 \x01(\t\x12\x1b\n\x06amount\x18\x02 \x01(\tB\x0b\xda\xde\x1f\x03Dec\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01"$\n\x08IntProto\x12\x18\n\x03int\x18\x01 \x01(\tB\x0b\xda\xde\x1f\x03Int\xc8\xde\x1f\x00"$\n\x08DecProto\x12\x18\n\x03dec\x18\x01 \x01(\tB\x0b\xda\xde\x1f\x03Dec\xc8\xde\x1f\x00B,Z"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.v1beta1.coin_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00'
    _COIN.fields_by_name['amount']._options = None
    _COIN.fields_by_name['amount']._serialized_options = b'\xda\xde\x1f\x03Int\xc8\xde\x1f\x00'
    _COIN._options = None
    _COIN._serialized_options = b'\xe8\xa0\x1f\x01'
    _DECCOIN.fields_by_name['amount']._options = None
    _DECCOIN.fields_by_name['amount']._serialized_options = b'\xda\xde\x1f\x03Dec\xc8\xde\x1f\x00'
    _DECCOIN._options = None
    _DECCOIN._serialized_options = b'\xe8\xa0\x1f\x01'
    _INTPROTO.fields_by_name['int']._options = None
    _INTPROTO.fields_by_name['int']._serialized_options = b'\xda\xde\x1f\x03Int\xc8\xde\x1f\x00'
    _DECPROTO.fields_by_name['dec']._options = None
    _DECPROTO.fields_by_name['dec']._serialized_options = b'\xda\xde\x1f\x03Dec\xc8\xde\x1f\x00'
    _COIN._serialized_start = 77
    _COIN._serialized_end = 133
    _DECCOIN._serialized_start = 135
    _DECCOIN._serialized_end = 194
    _INTPROTO._serialized_start = 196
    _INTPROTO._serialized_end = 232
    _DECPROTO._serialized_start = 234
    _DECPROTO._serialized_end = 270




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....cosmos.upgrade.v1beta1 import upgrade_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_upgrade__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/client/v1/client.proto\x12\x12ibc.core.client.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a$cosmos/upgrade/v1beta1/upgrade.proto"\x85\x01\n\x15IdentifiedClientState\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:"client_id"\x12C\n\x0cclient_state\x18\x02 \x01(\x0b2\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:"client_state""\x97\x01\n\x18ConsensusStateWithHeight\x120\n\x06height\x18\x01 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\x12I\n\x0fconsensus_state\x18\x02 \x01(\x0b2\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:"consensus_state""\xa9\x01\n\x15ClientConsensusStates\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:"client_id"\x12g\n\x10consensus_states\x18\x02 \x03(\x0b2,.ibc.core.client.v1.ConsensusStateWithHeightB\x1f\xf2\xde\x1f\x17yaml:"consensus_states"\xc8\xde\x1f\x00"\xb8\x01\n\x14ClientUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x127\n\x11subject_client_id\x18\x03 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"subject_client_id"\x12=\n\x14substitute_client_id\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:"substitute_client_id":\x04\x88\xa0\x1f\x00"\xcc\x01\n\x0fUpgradeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x120\n\x04plan\x18\x03 \x01(\x0b2\x1c.cosmos.upgrade.v1beta1.PlanB\x04\xc8\xde\x1f\x00\x12U\n\x15upgraded_client_state\x18\x04 \x01(\x0b2\x14.google.protobuf.AnyB \xf2\xde\x1f\x1cyaml:"upgraded_client_state":\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x01"|\n\x06Height\x123\n\x0frevision_number\x18\x01 \x01(\x04B\x1a\xf2\xde\x1f\x16yaml:"revision_number"\x123\n\x0frevision_height\x18\x02 \x01(\x04B\x1a\xf2\xde\x1f\x16yaml:"revision_height":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00"=\n\x06Params\x123\n\x0fallowed_clients\x18\x01 \x03(\tB\x1a\xf2\xde\x1f\x16yaml:"allowed_clients"B:Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.client_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v3/modules/core/02-client/types'
    _IDENTIFIEDCLIENTSTATE.fields_by_name['client_id']._options = None
    _IDENTIFIEDCLIENTSTATE.fields_by_name['client_id']._serialized_options = b'\xf2\xde\x1f\x10yaml:"client_id"'
    _IDENTIFIEDCLIENTSTATE.fields_by_name['client_state']._options = None
    _IDENTIFIEDCLIENTSTATE.fields_by_name['client_state']._serialized_options = b'\xf2\xde\x1f\x13yaml:"client_state"'
    _CONSENSUSSTATEWITHHEIGHT.fields_by_name['height']._options = None
    _CONSENSUSSTATEWITHHEIGHT.fields_by_name['height']._serialized_options = b'\xc8\xde\x1f\x00'
    _CONSENSUSSTATEWITHHEIGHT.fields_by_name['consensus_state']._options = None
    _CONSENSUSSTATEWITHHEIGHT.fields_by_name['consensus_state']._serialized_options = b'\xf2\xde\x1f\x16yaml:"consensus_state"'
    _CLIENTCONSENSUSSTATES.fields_by_name['client_id']._options = None
    _CLIENTCONSENSUSSTATES.fields_by_name['client_id']._serialized_options = b'\xf2\xde\x1f\x10yaml:"client_id"'
    _CLIENTCONSENSUSSTATES.fields_by_name['consensus_states']._options = None
    _CLIENTCONSENSUSSTATES.fields_by_name['consensus_states']._serialized_options = b'\xf2\xde\x1f\x17yaml:"consensus_states"\xc8\xde\x1f\x00'
    _CLIENTUPDATEPROPOSAL.fields_by_name['subject_client_id']._options = None
    _CLIENTUPDATEPROPOSAL.fields_by_name['subject_client_id']._serialized_options = b'\xf2\xde\x1f\x18yaml:"subject_client_id"'
    _CLIENTUPDATEPROPOSAL.fields_by_name['substitute_client_id']._options = None
    _CLIENTUPDATEPROPOSAL.fields_by_name['substitute_client_id']._serialized_options = b'\xf2\xde\x1f\x1byaml:"substitute_client_id"'
    _CLIENTUPDATEPROPOSAL._options = None
    _CLIENTUPDATEPROPOSAL._serialized_options = b'\x88\xa0\x1f\x00'
    _UPGRADEPROPOSAL.fields_by_name['plan']._options = None
    _UPGRADEPROPOSAL.fields_by_name['plan']._serialized_options = b'\xc8\xde\x1f\x00'
    _UPGRADEPROPOSAL.fields_by_name['upgraded_client_state']._options = None
    _UPGRADEPROPOSAL.fields_by_name['upgraded_client_state']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"upgraded_client_state"'
    _UPGRADEPROPOSAL._options = None
    _UPGRADEPROPOSAL._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x01'
    _HEIGHT.fields_by_name['revision_number']._options = None
    _HEIGHT.fields_by_name['revision_number']._serialized_options = b'\xf2\xde\x1f\x16yaml:"revision_number"'
    _HEIGHT.fields_by_name['revision_height']._options = None
    _HEIGHT.fields_by_name['revision_height']._serialized_options = b'\xf2\xde\x1f\x16yaml:"revision_height"'
    _HEIGHT._options = None
    _HEIGHT._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _PARAMS.fields_by_name['allowed_clients']._options = None
    _PARAMS.fields_by_name['allowed_clients']._serialized_options = b'\xf2\xde\x1f\x16yaml:"allowed_clients"'
    _IDENTIFIEDCLIENTSTATE._serialized_start = 143
    _IDENTIFIEDCLIENTSTATE._serialized_end = 276
    _CONSENSUSSTATEWITHHEIGHT._serialized_start = 279
    _CONSENSUSSTATEWITHHEIGHT._serialized_end = 430
    _CLIENTCONSENSUSSTATES._serialized_start = 433
    _CLIENTCONSENSUSSTATES._serialized_end = 602
    _CLIENTUPDATEPROPOSAL._serialized_start = 605
    _CLIENTUPDATEPROPOSAL._serialized_end = 789
    _UPGRADEPROPOSAL._serialized_start = 792
    _UPGRADEPROPOSAL._serialized_end = 996
    _HEIGHT._serialized_start = 998
    _HEIGHT._serialized_end = 1122
    _PARAMS._serialized_start = 1124
    _PARAMS._serialized_end = 1185




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ......ibc.applications.interchain_accounts.controller.v1 import query_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2

class QueryStub(object):
    'Query provides defines the gRPC querier service.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Params = channel.unary_unary('/ibc.applications.interchain_accounts.controller.v1.Query/Params', request_serializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString, response_deserializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsResponse.FromString)

class QueryServicer(object):
    'Query provides defines the gRPC querier service.\n    '

    def Params(self, request, context):
        'Params queries all parameters of the ICA controller submodule.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Params': grpc.unary_unary_rpc_method_handler(servicer.Params, request_deserializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsRequest.FromString, response_serializer=ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ibc.applications.interchain_accounts.controller.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query provides defines the gRPC querier service.\n    '

    @staticmethod
    def Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.interchain_accounts.controller.v1.Query/Params', ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString, ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_query__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.types import types_pb2 as _types_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class CanonicalBlockID(_message.Message):
    __slots__ = ['hash', 'part_set_header']
    HASH_FIELD_NUMBER: _ClassVar[int]
    PART_SET_HEADER_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    part_set_header: CanonicalPartSetHeader

    def __init__(self, hash: _Optional[bytes]=..., part_set_header: _Optional[_Union[(CanonicalPartSetHeader, _Mapping)]]=...) -> None:
        ...

class CanonicalPartSetHeader(_message.Message):
    __slots__ = ['hash', 'total']
    HASH_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    total: int

    def __init__(self, total: _Optional[int]=..., hash: _Optional[bytes]=...) -> None:
        ...

class CanonicalProposal(_message.Message):
    __slots__ = ['block_id', 'chain_id', 'height', 'pol_round', 'round', 'timestamp', 'type']
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    POL_ROUND_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    block_id: CanonicalBlockID
    chain_id: str
    height: int
    pol_round: int
    round: int
    timestamp: _timestamp_pb2.Timestamp
    type: _types_pb2.SignedMsgType

    def __init__(self, type: _Optional[_Union[(_types_pb2.SignedMsgType, str)]]=..., height: _Optional[int]=..., round: _Optional[int]=..., pol_round: _Optional[int]=..., block_id: _Optional[_Union[(CanonicalBlockID, _Mapping)]]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., chain_id: _Optional[str]=...) -> None:
        ...

class CanonicalVote(_message.Message):
    __slots__ = ['block_id', 'chain_id', 'height', 'round', 'timestamp', 'type']
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    block_id: CanonicalBlockID
    chain_id: str
    height: int
    round: int
    timestamp: _timestamp_pb2.Timestamp
    type: _types_pb2.SignedMsgType

    def __init__(self, type: _Optional[_Union[(_types_pb2.SignedMsgType, str)]]=..., height: _Optional[int]=..., round: _Optional[int]=..., block_id: _Optional[_Union[(CanonicalBlockID, _Mapping)]]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., chain_id: _Optional[str]=...) -> None:
        ...




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from .....ibc.applications.transfer.v1 import query_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2

class QueryStub(object):
    'Query provides defines the gRPC querier service.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.DenomTrace = channel.unary_unary('/ibc.applications.transfer.v1.Query/DenomTrace', request_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceRequest.SerializeToString, response_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceResponse.FromString)
        self.DenomTraces = channel.unary_unary('/ibc.applications.transfer.v1.Query/DenomTraces', request_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesRequest.SerializeToString, response_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesResponse.FromString)
        self.Params = channel.unary_unary('/ibc.applications.transfer.v1.Query/Params', request_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString, response_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsResponse.FromString)
        self.DenomHash = channel.unary_unary('/ibc.applications.transfer.v1.Query/DenomHash', request_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashRequest.SerializeToString, response_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashResponse.FromString)

class QueryServicer(object):
    'Query provides defines the gRPC querier service.\n    '

    def DenomTrace(self, request, context):
        'DenomTrace queries a denomination trace information.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomTraces(self, request, context):
        'DenomTraces queries all denomination traces.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        'Params queries all parameters of the ibc-transfer module.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomHash(self, request, context):
        'DenomHash queries a denomination hash information.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'DenomTrace': grpc.unary_unary_rpc_method_handler(servicer.DenomTrace, request_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceRequest.FromString, response_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceResponse.SerializeToString), 'DenomTraces': grpc.unary_unary_rpc_method_handler(servicer.DenomTraces, request_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesRequest.FromString, response_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesResponse.SerializeToString), 'Params': grpc.unary_unary_rpc_method_handler(servicer.Params, request_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsRequest.FromString, response_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString), 'DenomHash': grpc.unary_unary_rpc_method_handler(servicer.DenomHash, request_deserializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashRequest.FromString, response_serializer=ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ibc.applications.transfer.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query provides defines the gRPC querier service.\n    '

    @staticmethod
    def DenomTrace(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.transfer.v1.Query/DenomTrace', ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceRequest.SerializeToString, ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTraceResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomTraces(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.transfer.v1.Query/DenomTraces', ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesRequest.SerializeToString, ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomTracesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.transfer.v1.Query/Params', ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString, ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomHash(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.applications.transfer.v1.Query/DenomHash', ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashRequest.SerializeToString, ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2.QueryDenomHashResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentinel/plan/v2/msg.proto\x12\x10sentinel.plan.v2\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1esentinel/types/v1/status.proto"\xc6\x01\n\x10MsgCreateRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x125\n\x08duration\x18\x02 \x01(\x0b2\x19.google.protobuf.DurationB\x08\x98\xdf\x1f\x01\xc8\xde\x1f\x00\x12\x11\n\tgigabytes\x18\x03 \x01(\x03\x12[\n\x06prices\x18\x04 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins"d\n\x16MsgUpdateStatusRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12)\n\x06status\x18\x03 \x01(\x0e2\x19.sentinel.types.v1.Status"F\n\x12MsgLinkNodeRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07address\x18\x03 \x01(\t"H\n\x14MsgUnlinkNodeRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07address\x18\x03 \x01(\t"E\n\x13MsgSubscribeRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\r\n\x05denom\x18\x03 \x01(\t"\x13\n\x11MsgCreateResponse"\x19\n\x17MsgUpdateStatusResponse"\x15\n\x13MsgLinkNodeResponse"\x17\n\x15MsgUnlinkNodeResponse"\x16\n\x14MsgSubscribeResponse2\xe7\x03\n\nMsgService\x12T\n\tMsgCreate\x12".sentinel.plan.v2.MsgCreateRequest\x1a#.sentinel.plan.v2.MsgCreateResponse\x12f\n\x0fMsgUpdateStatus\x12(.sentinel.plan.v2.MsgUpdateStatusRequest\x1a).sentinel.plan.v2.MsgUpdateStatusResponse\x12Z\n\x0bMsgLinkNode\x12$.sentinel.plan.v2.MsgLinkNodeRequest\x1a%.sentinel.plan.v2.MsgLinkNodeResponse\x12`\n\rMsgUnlinkNode\x12&.sentinel.plan.v2.MsgUnlinkNodeRequest\x1a\'.sentinel.plan.v2.MsgUnlinkNodeResponse\x12]\n\x0cMsgSubscribe\x12%.sentinel.plan.v2.MsgSubscribeRequest\x1a&.sentinel.plan.v2.MsgSubscribeResponseB7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.msg_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _MSGCREATEREQUEST.fields_by_name['duration']._options = None
    _MSGCREATEREQUEST.fields_by_name['duration']._serialized_options = b'\x98\xdf\x1f\x01\xc8\xde\x1f\x00'
    _MSGCREATEREQUEST.fields_by_name['prices']._options = None
    _MSGCREATEREQUEST.fields_by_name['prices']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGUPDATESTATUSREQUEST.fields_by_name['id']._options = None
    _MSGUPDATESTATUSREQUEST.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _MSGLINKNODEREQUEST.fields_by_name['id']._options = None
    _MSGLINKNODEREQUEST.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _MSGUNLINKNODEREQUEST.fields_by_name['id']._options = None
    _MSGUNLINKNODEREQUEST.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _MSGSUBSCRIBEREQUEST.fields_by_name['id']._options = None
    _MSGSUBSCRIBEREQUEST.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _MSGCREATEREQUEST._serialized_start = 167
    _MSGCREATEREQUEST._serialized_end = 365
    _MSGUPDATESTATUSREQUEST._serialized_start = 367
    _MSGUPDATESTATUSREQUEST._serialized_end = 467
    _MSGLINKNODEREQUEST._serialized_start = 469
    _MSGLINKNODEREQUEST._serialized_end = 539
    _MSGUNLINKNODEREQUEST._serialized_start = 541
    _MSGUNLINKNODEREQUEST._serialized_end = 613
    _MSGSUBSCRIBEREQUEST._serialized_start = 615
    _MSGSUBSCRIBEREQUEST._serialized_end = 684
    _MSGCREATERESPONSE._serialized_start = 686
    _MSGCREATERESPONSE._serialized_end = 705
    _MSGUPDATESTATUSRESPONSE._serialized_start = 707
    _MSGUPDATESTATUSRESPONSE._serialized_end = 732
    _MSGLINKNODERESPONSE._serialized_start = 734
    _MSGLINKNODERESPONSE._serialized_end = 755
    _MSGUNLINKNODERESPONSE._serialized_start = 757
    _MSGUNLINKNODERESPONSE._serialized_end = 780
    _MSGSUBSCRIBERESPONSE._serialized_start = 782
    _MSGSUBSCRIBERESPONSE._serialized_end = 804
    _MSGSERVICE._serialized_start = 807
    _MSGSERVICE._serialized_end = 1294




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....cosmos.gov.v1beta1 import query_pb2 as cosmos_dot_gov_dot_v1beta1_dot_query__pb2

class QueryStub(object):
    'Query defines the gRPC querier service for gov module\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Proposal = channel.unary_unary('/cosmos.gov.v1beta1.Query/Proposal', request_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalRequest.SerializeToString, response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalResponse.FromString)
        self.Proposals = channel.unary_unary('/cosmos.gov.v1beta1.Query/Proposals', request_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalsRequest.SerializeToString, response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalsResponse.FromString)
        self.Vote = channel.unary_unary('/cosmos.gov.v1beta1.Query/Vote', request_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVoteRequest.SerializeToString, response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVoteResponse.FromString)
        self.Votes = channel.unary_unary('/cosmos.gov.v1beta1.Query/Votes', request_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVotesRequest.SerializeToString, response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVotesResponse.FromString)
        self.Params = channel.unary_unary('/cosmos.gov.v1beta1.Query/Params', request_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString)
        self.Deposit = channel.unary_unary('/cosmos.gov.v1beta1.Query/Deposit', request_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositRequest.SerializeToString, response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositResponse.FromString)
        self.Deposits = channel.unary_unary('/cosmos.gov.v1beta1.Query/Deposits', request_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositsRequest.SerializeToString, response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositsResponse.FromString)
        self.TallyResult = channel.unary_unary('/cosmos.gov.v1beta1.Query/TallyResult', request_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryTallyResultRequest.SerializeToString, response_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryTallyResultResponse.FromString)

class QueryServicer(object):
    'Query defines the gRPC querier service for gov module\n    '

    def Proposal(self, request, context):
        'Proposal queries proposal details based on ProposalID.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Proposals(self, request, context):
        'Proposals queries all proposals based on given status.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Vote(self, request, context):
        'Vote queries voted information based on proposalID, voterAddr.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Votes(self, request, context):
        'Votes queries votes of a given proposal.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        'Params queries all parameters of the gov module.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deposit(self, request, context):
        'Deposit queries single deposit information based proposalID, depositAddr.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deposits(self, request, context):
        'Deposits queries all deposits of a single proposal.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TallyResult(self, request, context):
        'TallyResult queries the tally of a proposal vote.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Proposal': grpc.unary_unary_rpc_method_handler(servicer.Proposal, request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalRequest.FromString, response_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalResponse.SerializeToString), 'Proposals': grpc.unary_unary_rpc_method_handler(servicer.Proposals, request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalsRequest.FromString, response_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalsResponse.SerializeToString), 'Vote': grpc.unary_unary_rpc_method_handler(servicer.Vote, request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVoteRequest.FromString, response_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVoteResponse.SerializeToString), 'Votes': grpc.unary_unary_rpc_method_handler(servicer.Votes, request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVotesRequest.FromString, response_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVotesResponse.SerializeToString), 'Params': grpc.unary_unary_rpc_method_handler(servicer.Params, request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString, response_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString), 'Deposit': grpc.unary_unary_rpc_method_handler(servicer.Deposit, request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositRequest.FromString, response_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositResponse.SerializeToString), 'Deposits': grpc.unary_unary_rpc_method_handler(servicer.Deposits, request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositsRequest.FromString, response_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositsResponse.SerializeToString), 'TallyResult': grpc.unary_unary_rpc_method_handler(servicer.TallyResult, request_deserializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryTallyResultRequest.FromString, response_serializer=cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryTallyResultResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.gov.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query defines the gRPC querier service for gov module\n    '

    @staticmethod
    def Proposal(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Query/Proposal', cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalRequest.SerializeToString, cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Proposals(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Query/Proposals', cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalsRequest.SerializeToString, cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryProposalsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Vote(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Query/Vote', cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVoteRequest.SerializeToString, cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVoteResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Votes(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Query/Votes', cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVotesRequest.SerializeToString, cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryVotesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Query/Params', cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deposit(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Query/Deposit', cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositRequest.SerializeToString, cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deposits(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Query/Deposits', cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositsRequest.SerializeToString, cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryDepositsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TallyResult(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.gov.v1beta1.Query/TallyResult', cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryTallyResultRequest.SerializeToString, cosmos_dot_gov_dot_v1beta1_dot_query__pb2.QueryTallyResultResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/distribution/v1beta1/tx.proto\x12\x1bcosmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto"\x91\x01\n\x15MsgSetWithdrawAddress\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x125\n\x10withdraw_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:"withdraw_address":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1f\n\x1dMsgSetWithdrawAddressResponse"\x98\x01\n\x1aMsgWithdrawDelegatorReward\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x127\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"$\n"MsgWithdrawDelegatorRewardResponse"c\n\x1eMsgWithdrawValidatorCommission\x127\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"(\n&MsgWithdrawValidatorCommissionResponse"\x90\x01\n\x14MsgFundCommunityPool\x12[\n\x06amount\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tdepositor\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1e\n\x1cMsgFundCommunityPoolResponse2\xc8\x04\n\x03Msg\x12\x84\x01\n\x12SetWithdrawAddress\x122.cosmos.distribution.v1beta1.MsgSetWithdrawAddress\x1a:.cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse\x12\x93\x01\n\x17WithdrawDelegatorReward\x127.cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward\x1a?.cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse\x12\x9f\x01\n\x1bWithdrawValidatorCommission\x12;.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission\x1aC.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse\x12\x81\x01\n\x11FundCommunityPool\x121.cosmos.distribution.v1beta1.MsgFundCommunityPool\x1a9.cosmos.distribution.v1beta1.MsgFundCommunityPoolResponseB7Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01'
    _MSGSETWITHDRAWADDRESS.fields_by_name['delegator_address']._options = None
    _MSGSETWITHDRAWADDRESS.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _MSGSETWITHDRAWADDRESS.fields_by_name['withdraw_address']._options = None
    _MSGSETWITHDRAWADDRESS.fields_by_name['withdraw_address']._serialized_options = b'\xf2\xde\x1f\x17yaml:"withdraw_address"'
    _MSGSETWITHDRAWADDRESS._options = None
    _MSGSETWITHDRAWADDRESS._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGWITHDRAWDELEGATORREWARD.fields_by_name['delegator_address']._options = None
    _MSGWITHDRAWDELEGATORREWARD.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _MSGWITHDRAWDELEGATORREWARD.fields_by_name['validator_address']._options = None
    _MSGWITHDRAWDELEGATORREWARD.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _MSGWITHDRAWDELEGATORREWARD._options = None
    _MSGWITHDRAWDELEGATORREWARD._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGWITHDRAWVALIDATORCOMMISSION.fields_by_name['validator_address']._options = None
    _MSGWITHDRAWVALIDATORCOMMISSION.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _MSGWITHDRAWVALIDATORCOMMISSION._options = None
    _MSGWITHDRAWVALIDATORCOMMISSION._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGFUNDCOMMUNITYPOOL.fields_by_name['amount']._options = None
    _MSGFUNDCOMMUNITYPOOL.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _MSGFUNDCOMMUNITYPOOL._options = None
    _MSGFUNDCOMMUNITYPOOL._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGSETWITHDRAWADDRESS._serialized_start = 124
    _MSGSETWITHDRAWADDRESS._serialized_end = 269
    _MSGSETWITHDRAWADDRESSRESPONSE._serialized_start = 271
    _MSGSETWITHDRAWADDRESSRESPONSE._serialized_end = 302
    _MSGWITHDRAWDELEGATORREWARD._serialized_start = 305
    _MSGWITHDRAWDELEGATORREWARD._serialized_end = 457
    _MSGWITHDRAWDELEGATORREWARDRESPONSE._serialized_start = 459
    _MSGWITHDRAWDELEGATORREWARDRESPONSE._serialized_end = 495
    _MSGWITHDRAWVALIDATORCOMMISSION._serialized_start = 497
    _MSGWITHDRAWVALIDATORCOMMISSION._serialized_end = 596
    _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE._serialized_start = 598
    _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE._serialized_end = 638
    _MSGFUNDCOMMUNITYPOOL._serialized_start = 641
    _MSGFUNDCOMMUNITYPOOL._serialized_end = 785
    _MSGFUNDCOMMUNITYPOOLRESPONSE._serialized_start = 787
    _MSGFUNDCOMMUNITYPOOLRESPONSE._serialized_end = 817
    _MSG._serialized_start = 820
    _MSG._serialized_end = 1404




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from ....cosmos.tx.v1beta1 import tx_pb2 as cosmos_dot_tx_dot_v1beta1_dot_tx__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from ....tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fcosmos/tx/v1beta1/service.proto\x12\x11cosmos.tx.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a\x1acosmos/tx/v1beta1/tx.proto\x1a\x14gogoproto/gogo.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto"\x8e\x01\n\x12GetTxsEventRequest\x12\x0e\n\x06events\x18\x01 \x03(\t\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest\x12,\n\x08order_by\x18\x03 \x01(\x0e2\x1a.cosmos.tx.v1beta1.OrderBy"\xb2\x01\n\x13GetTxsEventResponse\x12"\n\x03txs\x18\x01 \x03(\x0b2\x15.cosmos.tx.v1beta1.Tx\x12:\n\x0ctx_responses\x18\x02 \x03(\x0b2$.cosmos.base.abci.v1beta1.TxResponse\x12;\n\npagination\x18\x03 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"V\n\x12BroadcastTxRequest\x12\x10\n\x08tx_bytes\x18\x01 \x01(\x0c\x12.\n\x04mode\x18\x02 \x01(\x0e2 .cosmos.tx.v1beta1.BroadcastMode"P\n\x13BroadcastTxResponse\x129\n\x0btx_response\x18\x01 \x01(\x0b2$.cosmos.base.abci.v1beta1.TxResponse"J\n\x0fSimulateRequest\x12%\n\x02tx\x18\x01 \x01(\x0b2\x15.cosmos.tx.v1beta1.TxB\x02\x18\x01\x12\x10\n\x08tx_bytes\x18\x02 \x01(\x0c"y\n\x10SimulateResponse\x123\n\x08gas_info\x18\x01 \x01(\x0b2!.cosmos.base.abci.v1beta1.GasInfo\x120\n\x06result\x18\x02 \x01(\x0b2 .cosmos.base.abci.v1beta1.Result"\x1c\n\x0cGetTxRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t"m\n\rGetTxResponse\x12!\n\x02tx\x18\x01 \x01(\x0b2\x15.cosmos.tx.v1beta1.Tx\x129\n\x0btx_response\x18\x02 \x01(\x0b2$.cosmos.base.abci.v1beta1.TxResponse"d\n\x16GetBlockWithTxsRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\xcf\x01\n\x17GetBlockWithTxsResponse\x12"\n\x03txs\x18\x01 \x03(\x0b2\x15.cosmos.tx.v1beta1.Tx\x12+\n\x08block_id\x18\x02 \x01(\x0b2\x19.tendermint.types.BlockID\x12&\n\x05block\x18\x03 \x01(\x0b2\x17.tendermint.types.Block\x12;\n\npagination\x18\x04 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse*H\n\x07OrderBy\x12\x18\n\x14ORDER_BY_UNSPECIFIED\x10\x00\x12\x10\n\x0cORDER_BY_ASC\x10\x01\x12\x11\n\rORDER_BY_DESC\x10\x02*|\n\rBroadcastMode\x12\x1e\n\x1aBROADCAST_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14BROADCAST_MODE_BLOCK\x10\x01\x12\x17\n\x13BROADCAST_MODE_SYNC\x10\x02\x12\x18\n\x14BROADCAST_MODE_ASYNC\x10\x032\x92\x05\n\x07Service\x12{\n\x08Simulate\x12".cosmos.tx.v1beta1.SimulateRequest\x1a#.cosmos.tx.v1beta1.SimulateResponse"&\x82\xd3\xe4\x93\x02 "\x1b/cosmos/tx/v1beta1/simulate:\x01*\x12q\n\x05GetTx\x12\x1f.cosmos.tx.v1beta1.GetTxRequest\x1a .cosmos.tx.v1beta1.GetTxResponse"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/tx/v1beta1/txs/{hash}\x12\x7f\n\x0bBroadcastTx\x12%.cosmos.tx.v1beta1.BroadcastTxRequest\x1a&.cosmos.tx.v1beta1.BroadcastTxResponse"!\x82\xd3\xe4\x93\x02\x1b"\x16/cosmos/tx/v1beta1/txs:\x01*\x12|\n\x0bGetTxsEvent\x12%.cosmos.tx.v1beta1.GetTxsEventRequest\x1a&.cosmos.tx.v1beta1.GetTxsEventResponse"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmos/tx/v1beta1/txs\x12\x97\x01\n\x0fGetBlockWithTxs\x12).cosmos.tx.v1beta1.GetBlockWithTxsRequest\x1a*.cosmos.tx.v1beta1.GetBlockWithTxsResponse"-\x82\xd3\xe4\x93\x02\'\x12%/cosmos/tx/v1beta1/txs/block/{height}B+Z%github.com/cosmos/cosmos-sdk/types/tx\xc0\xe3\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.v1beta1.service_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z%github.com/cosmos/cosmos-sdk/types/tx\xc0\xe3\x1e\x01'
    _SIMULATEREQUEST.fields_by_name['tx']._options = None
    _SIMULATEREQUEST.fields_by_name['tx']._serialized_options = b'\x18\x01'
    _SERVICE.methods_by_name['Simulate']._options = None
    _SERVICE.methods_by_name['Simulate']._serialized_options = b'\x82\xd3\xe4\x93\x02 "\x1b/cosmos/tx/v1beta1/simulate:\x01*'
    _SERVICE.methods_by_name['GetTx']._options = None
    _SERVICE.methods_by_name['GetTx']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/tx/v1beta1/txs/{hash}'
    _SERVICE.methods_by_name['BroadcastTx']._options = None
    _SERVICE.methods_by_name['BroadcastTx']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1b"\x16/cosmos/tx/v1beta1/txs:\x01*'
    _SERVICE.methods_by_name['GetTxsEvent']._options = None
    _SERVICE.methods_by_name['GetTxsEvent']._serialized_options = b'\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmos/tx/v1beta1/txs'
    _SERVICE.methods_by_name['GetBlockWithTxs']._options = None
    _SERVICE.methods_by_name['GetBlockWithTxs']._serialized_options = b"\x82\xd3\xe4\x93\x02'\x12%/cosmos/tx/v1beta1/txs/block/{height}"
    _ORDERBY._serialized_start = 1423
    _ORDERBY._serialized_end = 1495
    _BROADCASTMODE._serialized_start = 1497
    _BROADCASTMODE._serialized_end = 1621
    _GETTXSEVENTREQUEST._serialized_start = 276
    _GETTXSEVENTREQUEST._serialized_end = 418
    _GETTXSEVENTRESPONSE._serialized_start = 421
    _GETTXSEVENTRESPONSE._serialized_end = 599
    _BROADCASTTXREQUEST._serialized_start = 601
    _BROADCASTTXREQUEST._serialized_end = 687
    _BROADCASTTXRESPONSE._serialized_start = 689
    _BROADCASTTXRESPONSE._serialized_end = 769
    _SIMULATEREQUEST._serialized_start = 771
    _SIMULATEREQUEST._serialized_end = 845
    _SIMULATERESPONSE._serialized_start = 847
    _SIMULATERESPONSE._serialized_end = 968
    _GETTXREQUEST._serialized_start = 970
    _GETTXREQUEST._serialized_end = 998
    _GETTXRESPONSE._serialized_start = 1000
    _GETTXRESPONSE._serialized_end = 1109
    _GETBLOCKWITHTXSREQUEST._serialized_start = 1111
    _GETBLOCKWITHTXSREQUEST._serialized_end = 1211
    _GETBLOCKWITHTXSRESPONSE._serialized_start = 1214
    _GETBLOCKWITHTXSRESPONSE._serialized_end = 1421
    _SERVICE._serialized_start = 1624
    _SERVICE._serialized_end = 2282




from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class AppDescriptor(_message.Message):
    __slots__ = ['authn', 'chain', 'codec', 'configuration', 'query_services', 'tx']
    AUTHN_FIELD_NUMBER: _ClassVar[int]
    CHAIN_FIELD_NUMBER: _ClassVar[int]
    CODEC_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    QUERY_SERVICES_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    authn: AuthnDescriptor
    chain: ChainDescriptor
    codec: CodecDescriptor
    configuration: ConfigurationDescriptor
    query_services: QueryServicesDescriptor
    tx: TxDescriptor

    def __init__(self, authn: _Optional[_Union[(AuthnDescriptor, _Mapping)]]=..., chain: _Optional[_Union[(ChainDescriptor, _Mapping)]]=..., codec: _Optional[_Union[(CodecDescriptor, _Mapping)]]=..., configuration: _Optional[_Union[(ConfigurationDescriptor, _Mapping)]]=..., query_services: _Optional[_Union[(QueryServicesDescriptor, _Mapping)]]=..., tx: _Optional[_Union[(TxDescriptor, _Mapping)]]=...) -> None:
        ...

class AuthnDescriptor(_message.Message):
    __slots__ = ['sign_modes']
    SIGN_MODES_FIELD_NUMBER: _ClassVar[int]
    sign_modes: _containers.RepeatedCompositeFieldContainer[SigningModeDescriptor]

    def __init__(self, sign_modes: _Optional[_Iterable[_Union[(SigningModeDescriptor, _Mapping)]]]=...) -> None:
        ...

class ChainDescriptor(_message.Message):
    __slots__ = ['id']
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str

    def __init__(self, id: _Optional[str]=...) -> None:
        ...

class CodecDescriptor(_message.Message):
    __slots__ = ['interfaces']
    INTERFACES_FIELD_NUMBER: _ClassVar[int]
    interfaces: _containers.RepeatedCompositeFieldContainer[InterfaceDescriptor]

    def __init__(self, interfaces: _Optional[_Iterable[_Union[(InterfaceDescriptor, _Mapping)]]]=...) -> None:
        ...

class ConfigurationDescriptor(_message.Message):
    __slots__ = ['bech32_account_address_prefix']
    BECH32_ACCOUNT_ADDRESS_PREFIX_FIELD_NUMBER: _ClassVar[int]
    bech32_account_address_prefix: str

    def __init__(self, bech32_account_address_prefix: _Optional[str]=...) -> None:
        ...

class GetAuthnDescriptorRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetAuthnDescriptorResponse(_message.Message):
    __slots__ = ['authn']
    AUTHN_FIELD_NUMBER: _ClassVar[int]
    authn: AuthnDescriptor

    def __init__(self, authn: _Optional[_Union[(AuthnDescriptor, _Mapping)]]=...) -> None:
        ...

class GetChainDescriptorRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetChainDescriptorResponse(_message.Message):
    __slots__ = ['chain']
    CHAIN_FIELD_NUMBER: _ClassVar[int]
    chain: ChainDescriptor

    def __init__(self, chain: _Optional[_Union[(ChainDescriptor, _Mapping)]]=...) -> None:
        ...

class GetCodecDescriptorRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetCodecDescriptorResponse(_message.Message):
    __slots__ = ['codec']
    CODEC_FIELD_NUMBER: _ClassVar[int]
    codec: CodecDescriptor

    def __init__(self, codec: _Optional[_Union[(CodecDescriptor, _Mapping)]]=...) -> None:
        ...

class GetConfigurationDescriptorRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetConfigurationDescriptorResponse(_message.Message):
    __slots__ = ['config']
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: ConfigurationDescriptor

    def __init__(self, config: _Optional[_Union[(ConfigurationDescriptor, _Mapping)]]=...) -> None:
        ...

class GetQueryServicesDescriptorRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetQueryServicesDescriptorResponse(_message.Message):
    __slots__ = ['queries']
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    queries: QueryServicesDescriptor

    def __init__(self, queries: _Optional[_Union[(QueryServicesDescriptor, _Mapping)]]=...) -> None:
        ...

class GetTxDescriptorRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class GetTxDescriptorResponse(_message.Message):
    __slots__ = ['tx']
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: TxDescriptor

    def __init__(self, tx: _Optional[_Union[(TxDescriptor, _Mapping)]]=...) -> None:
        ...

class InterfaceAcceptingMessageDescriptor(_message.Message):
    __slots__ = ['field_descriptor_names', 'fullname']
    FIELD_DESCRIPTOR_NAMES_FIELD_NUMBER: _ClassVar[int]
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    field_descriptor_names: _containers.RepeatedScalarFieldContainer[str]
    fullname: str

    def __init__(self, fullname: _Optional[str]=..., field_descriptor_names: _Optional[_Iterable[str]]=...) -> None:
        ...

class InterfaceDescriptor(_message.Message):
    __slots__ = ['fullname', 'interface_accepting_messages', 'interface_implementers']
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_ACCEPTING_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_IMPLEMENTERS_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    interface_accepting_messages: _containers.RepeatedCompositeFieldContainer[InterfaceAcceptingMessageDescriptor]
    interface_implementers: _containers.RepeatedCompositeFieldContainer[InterfaceImplementerDescriptor]

    def __init__(self, fullname: _Optional[str]=..., interface_accepting_messages: _Optional[_Iterable[_Union[(InterfaceAcceptingMessageDescriptor, _Mapping)]]]=..., interface_implementers: _Optional[_Iterable[_Union[(InterfaceImplementerDescriptor, _Mapping)]]]=...) -> None:
        ...

class InterfaceImplementerDescriptor(_message.Message):
    __slots__ = ['fullname', 'type_url']
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    type_url: str

    def __init__(self, fullname: _Optional[str]=..., type_url: _Optional[str]=...) -> None:
        ...

class MsgDescriptor(_message.Message):
    __slots__ = ['msg_type_url']
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    msg_type_url: str

    def __init__(self, msg_type_url: _Optional[str]=...) -> None:
        ...

class QueryMethodDescriptor(_message.Message):
    __slots__ = ['full_query_path', 'name']
    FULL_QUERY_PATH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    full_query_path: str
    name: str

    def __init__(self, name: _Optional[str]=..., full_query_path: _Optional[str]=...) -> None:
        ...

class QueryServiceDescriptor(_message.Message):
    __slots__ = ['fullname', 'is_module', 'methods']
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    IS_MODULE_FIELD_NUMBER: _ClassVar[int]
    METHODS_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    is_module: bool
    methods: _containers.RepeatedCompositeFieldContainer[QueryMethodDescriptor]

    def __init__(self, fullname: _Optional[str]=..., is_module: bool=..., methods: _Optional[_Iterable[_Union[(QueryMethodDescriptor, _Mapping)]]]=...) -> None:
        ...

class QueryServicesDescriptor(_message.Message):
    __slots__ = ['query_services']
    QUERY_SERVICES_FIELD_NUMBER: _ClassVar[int]
    query_services: _containers.RepeatedCompositeFieldContainer[QueryServiceDescriptor]

    def __init__(self, query_services: _Optional[_Iterable[_Union[(QueryServiceDescriptor, _Mapping)]]]=...) -> None:
        ...

class SigningModeDescriptor(_message.Message):
    __slots__ = ['authn_info_provider_method_fullname', 'name', 'number']
    AUTHN_INFO_PROVIDER_METHOD_FULLNAME_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    authn_info_provider_method_fullname: str
    name: str
    number: int

    def __init__(self, name: _Optional[str]=..., number: _Optional[int]=..., authn_info_provider_method_fullname: _Optional[str]=...) -> None:
        ...

class TxDescriptor(_message.Message):
    __slots__ = ['fullname', 'msgs']
    FULLNAME_FIELD_NUMBER: _ClassVar[int]
    MSGS_FIELD_NUMBER: _ClassVar[int]
    fullname: str
    msgs: _containers.RepeatedCompositeFieldContainer[MsgDescriptor]

    def __init__(self, fullname: _Optional[str]=..., msgs: _Optional[_Iterable[_Union[(MsgDescriptor, _Mapping)]]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.staking.v1beta1 import staking_pb2 as _staking_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['delegations', 'exported', 'last_total_power', 'last_validator_powers', 'params', 'redelegations', 'unbonding_delegations', 'validators']
    DELEGATIONS_FIELD_NUMBER: _ClassVar[int]
    EXPORTED_FIELD_NUMBER: _ClassVar[int]
    LAST_TOTAL_POWER_FIELD_NUMBER: _ClassVar[int]
    LAST_VALIDATOR_POWERS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    REDELEGATIONS_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_DELEGATIONS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    delegations: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Delegation]
    exported: bool
    last_total_power: bytes
    last_validator_powers: _containers.RepeatedCompositeFieldContainer[LastValidatorPower]
    params: _staking_pb2.Params
    redelegations: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Redelegation]
    unbonding_delegations: _containers.RepeatedCompositeFieldContainer[_staking_pb2.UnbondingDelegation]
    validators: _containers.RepeatedCompositeFieldContainer[_staking_pb2.Validator]

    def __init__(self, params: _Optional[_Union[(_staking_pb2.Params, _Mapping)]]=..., last_total_power: _Optional[bytes]=..., last_validator_powers: _Optional[_Iterable[_Union[(LastValidatorPower, _Mapping)]]]=..., validators: _Optional[_Iterable[_Union[(_staking_pb2.Validator, _Mapping)]]]=..., delegations: _Optional[_Iterable[_Union[(_staking_pb2.Delegation, _Mapping)]]]=..., unbonding_delegations: _Optional[_Iterable[_Union[(_staking_pb2.UnbondingDelegation, _Mapping)]]]=..., redelegations: _Optional[_Iterable[_Union[(_staking_pb2.Redelegation, _Mapping)]]]=..., exported: bool=...) -> None:
        ...

class LastValidatorPower(_message.Message):
    __slots__ = ['address', 'power']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    POWER_FIELD_NUMBER: _ClassVar[int]
    address: str
    power: int

    def __init__(self, address: _Optional[str]=..., power: _Optional[int]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.session.v2 import params_pb2 as sentinel_dot_session_dot_v2_dot_params__pb2
from ....sentinel.session.v2 import session_pb2 as sentinel_dot_session_dot_v2_dot_session__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!sentinel/session/v2/genesis.proto\x12\x13sentinel.session.v2\x1a\x14gogoproto/gogo.proto\x1a sentinel/session/v2/params.proto\x1a!sentinel/session/v2/session.proto"w\n\x0cGenesisState\x124\n\x08sessions\x18\x01 \x03(\x0b2\x1c.sentinel.session.v2.SessionB\x04\xc8\xde\x1f\x00\x121\n\x06params\x18\x02 \x01(\x0b2\x1b.sentinel.session.v2.ParamsB\x04\xc8\xde\x1f\x00B:Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.session.v2.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/session/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _GENESISSTATE.fields_by_name['sessions']._options = None
    _GENESISSTATE.fields_by_name['sessions']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE._serialized_start = 149
    _GENESISSTATE._serialized_end = 268




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...google.api import http_pb2 as google_dot_api_dot_http__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgoogle/api/annotations.proto\x12\ngoogle.api\x1a\x15google/api/http.proto\x1a google/protobuf/descriptor.proto:E\n\x04http\x12\x1e.google.protobuf.MethodOptions\x18\xb0\xca\xbc" \x01(\x0b2\x14.google.api.HttpRuleBn\n\x0ecom.google.apiB\x10AnnotationsProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xa2\x02\x04GAPIb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.annotations_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(http)
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'\n\x0ecom.google.apiB\x10AnnotationsProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xa2\x02\x04GAPI'




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/version/types.proto\x12\x12tendermint.version\x1a\x14gogoproto/gogo.proto")\n\x03App\x12\x10\n\x08protocol\x18\x01 \x01(\x04\x12\x10\n\x08software\x18\x02 \x01(\t"-\n\tConsensus\x12\r\n\x05block\x18\x01 \x01(\x04\x12\x0b\n\x03app\x18\x02 \x01(\x04:\x04\xe8\xa0\x1f\x01B;Z9github.com/tendermint/tendermint/proto/tendermint/versionb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.version.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z9github.com/tendermint/tendermint/proto/tendermint/version'
    _CONSENSUS._options = None
    _CONSENSUS._serialized_options = b'\xe8\xa0\x1f\x01'
    _APP._serialized_start = 76
    _APP._serialized_end = 117
    _CONSENSUS._serialized_start = 119
    _CONSENSUS._serialized_end = 164




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ecosmos/crisis/v1beta1/tx.proto\x12\x15cosmos.crisis.v1beta1\x1a\x14gogoproto/gogo.proto"\xa4\x01\n\x12MsgVerifyInvariant\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12?\n\x15invariant_module_name\x18\x02 \x01(\tB \xf2\xde\x1f\x1cyaml:"invariant_module_name"\x123\n\x0finvariant_route\x18\x03 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:"invariant_route":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1c\n\x1aMsgVerifyInvariantResponse2v\n\x03Msg\x12o\n\x0fVerifyInvariant\x12).cosmos.crisis.v1beta1.MsgVerifyInvariant\x1a1.cosmos.crisis.v1beta1.MsgVerifyInvariantResponseB-Z+github.com/cosmos/cosmos-sdk/x/crisis/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crisis.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/crisis/types'
    _MSGVERIFYINVARIANT.fields_by_name['invariant_module_name']._options = None
    _MSGVERIFYINVARIANT.fields_by_name['invariant_module_name']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"invariant_module_name"'
    _MSGVERIFYINVARIANT.fields_by_name['invariant_route']._options = None
    _MSGVERIFYINVARIANT.fields_by_name['invariant_route']._serialized_options = b'\xf2\xde\x1f\x16yaml:"invariant_route"'
    _MSGVERIFYINVARIANT._options = None
    _MSGVERIFYINVARIANT._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGVERIFYINVARIANT._serialized_start = 80
    _MSGVERIFYINVARIANT._serialized_end = 244
    _MSGVERIFYINVARIANTRESPONSE._serialized_start = 246
    _MSGVERIFYINVARIANTRESPONSE._serialized_end = 274
    _MSG._serialized_start = 276
    _MSG._serialized_end = 394




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from .....ibc.core.client.v1 import query_pb2 as ibc_dot_core_dot_client_dot_v1_dot_query__pb2

class QueryStub(object):
    'Query provides defines the gRPC querier service\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.ClientState = channel.unary_unary('/ibc.core.client.v1.Query/ClientState', request_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStateRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStateResponse.FromString)
        self.ClientStates = channel.unary_unary('/ibc.core.client.v1.Query/ClientStates', request_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatesRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatesResponse.FromString)
        self.ConsensusState = channel.unary_unary('/ibc.core.client.v1.Query/ConsensusState', request_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStateRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStateResponse.FromString)
        self.ConsensusStates = channel.unary_unary('/ibc.core.client.v1.Query/ConsensusStates', request_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStatesRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStatesResponse.FromString)
        self.ClientStatus = channel.unary_unary('/ibc.core.client.v1.Query/ClientStatus', request_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatusRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatusResponse.FromString)
        self.ClientParams = channel.unary_unary('/ibc.core.client.v1.Query/ClientParams', request_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientParamsRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientParamsResponse.FromString)
        self.UpgradedClientState = channel.unary_unary('/ibc.core.client.v1.Query/UpgradedClientState', request_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedClientStateRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedClientStateResponse.FromString)
        self.UpgradedConsensusState = channel.unary_unary('/ibc.core.client.v1.Query/UpgradedConsensusState', request_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedConsensusStateRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedConsensusStateResponse.FromString)

class QueryServicer(object):
    'Query provides defines the gRPC querier service\n    '

    def ClientState(self, request, context):
        'ClientState queries an IBC light client.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClientStates(self, request, context):
        'ClientStates queries all the IBC light clients of a chain.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConsensusState(self, request, context):
        'ConsensusState queries a consensus state associated with a client state at\n        a given height.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConsensusStates(self, request, context):
        'ConsensusStates queries all the consensus state associated with a given\n        client.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClientStatus(self, request, context):
        'Status queries the status of an IBC client.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClientParams(self, request, context):
        'ClientParams queries all parameters of the ibc client.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpgradedClientState(self, request, context):
        'UpgradedClientState queries an Upgraded IBC light client.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpgradedConsensusState(self, request, context):
        'UpgradedConsensusState queries an Upgraded IBC consensus state.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'ClientState': grpc.unary_unary_rpc_method_handler(servicer.ClientState, request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStateRequest.FromString, response_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStateResponse.SerializeToString), 'ClientStates': grpc.unary_unary_rpc_method_handler(servicer.ClientStates, request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatesRequest.FromString, response_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatesResponse.SerializeToString), 'ConsensusState': grpc.unary_unary_rpc_method_handler(servicer.ConsensusState, request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStateRequest.FromString, response_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStateResponse.SerializeToString), 'ConsensusStates': grpc.unary_unary_rpc_method_handler(servicer.ConsensusStates, request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStatesRequest.FromString, response_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStatesResponse.SerializeToString), 'ClientStatus': grpc.unary_unary_rpc_method_handler(servicer.ClientStatus, request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatusRequest.FromString, response_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatusResponse.SerializeToString), 'ClientParams': grpc.unary_unary_rpc_method_handler(servicer.ClientParams, request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientParamsRequest.FromString, response_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientParamsResponse.SerializeToString), 'UpgradedClientState': grpc.unary_unary_rpc_method_handler(servicer.UpgradedClientState, request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedClientStateRequest.FromString, response_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedClientStateResponse.SerializeToString), 'UpgradedConsensusState': grpc.unary_unary_rpc_method_handler(servicer.UpgradedConsensusState, request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedConsensusStateRequest.FromString, response_serializer=ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedConsensusStateResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ibc.core.client.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query provides defines the gRPC querier service\n    '

    @staticmethod
    def ClientState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.client.v1.Query/ClientState', ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStateRequest.SerializeToString, ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClientStates(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.client.v1.Query/ClientStates', ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatesRequest.SerializeToString, ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConsensusState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.client.v1.Query/ConsensusState', ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStateRequest.SerializeToString, ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConsensusStates(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.client.v1.Query/ConsensusStates', ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStatesRequest.SerializeToString, ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryConsensusStatesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClientStatus(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.client.v1.Query/ClientStatus', ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatusRequest.SerializeToString, ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientStatusResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClientParams(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.client.v1.Query/ClientParams', ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientParamsRequest.SerializeToString, ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryClientParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpgradedClientState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.client.v1.Query/UpgradedClientState', ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedClientStateRequest.SerializeToString, ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedClientStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpgradedConsensusState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.client.v1.Query/UpgradedConsensusState', ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedConsensusStateRequest.SerializeToString, ibc_dot_core_dot_client_dot_v1_dot_query__pb2.QueryUpgradedConsensusStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class DominoOp(_message.Message):
    __slots__ = ['input', 'key', 'output']
    INPUT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    input: str
    key: str
    output: str

    def __init__(self, key: _Optional[str]=..., input: _Optional[str]=..., output: _Optional[str]=...) -> None:
        ...

class Proof(_message.Message):
    __slots__ = ['aunts', 'index', 'leaf_hash', 'total']
    AUNTS_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    LEAF_HASH_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    aunts: _containers.RepeatedScalarFieldContainer[bytes]
    index: int
    leaf_hash: bytes
    total: int

    def __init__(self, total: _Optional[int]=..., index: _Optional[int]=..., leaf_hash: _Optional[bytes]=..., aunts: _Optional[_Iterable[bytes]]=...) -> None:
        ...

class ProofOp(_message.Message):
    __slots__ = ['data', 'key', 'type']
    DATA_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    key: bytes
    type: str

    def __init__(self, type: _Optional[str]=..., key: _Optional[bytes]=..., data: _Optional[bytes]=...) -> None:
        ...

class ProofOps(_message.Message):
    __slots__ = ['ops']
    OPS_FIELD_NUMBER: _ClassVar[int]
    ops: _containers.RepeatedCompositeFieldContainer[ProofOp]

    def __init__(self, ops: _Optional[_Iterable[_Union[(ProofOp, _Mapping)]]]=...) -> None:
        ...

class ValueOp(_message.Message):
    __slots__ = ['key', 'proof']
    KEY_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    proof: Proof

    def __init__(self, key: _Optional[bytes]=..., proof: _Optional[_Union[(Proof, _Mapping)]]=...) -> None:
        ...




from cosmos.crypto.multisig.v1beta1 import multisig_pb2 as _multisig_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor
SIGN_MODE_DIRECT: SignMode
SIGN_MODE_EIP_191: SignMode
SIGN_MODE_LEGACY_AMINO_JSON: SignMode
SIGN_MODE_TEXTUAL: SignMode
SIGN_MODE_UNSPECIFIED: SignMode

class SignatureDescriptor(_message.Message):
    __slots__ = ['data', 'public_key', 'sequence']

    class Data(_message.Message):
        __slots__ = ['multi', 'single']

        class Multi(_message.Message):
            __slots__ = ['bitarray', 'signatures']
            BITARRAY_FIELD_NUMBER: _ClassVar[int]
            SIGNATURES_FIELD_NUMBER: _ClassVar[int]
            bitarray: _multisig_pb2.CompactBitArray
            signatures: _containers.RepeatedCompositeFieldContainer[SignatureDescriptor.Data]

            def __init__(self, bitarray: _Optional[_Union[(_multisig_pb2.CompactBitArray, _Mapping)]]=..., signatures: _Optional[_Iterable[_Union[(SignatureDescriptor.Data, _Mapping)]]]=...) -> None:
                ...

        class Single(_message.Message):
            __slots__ = ['mode', 'signature']
            MODE_FIELD_NUMBER: _ClassVar[int]
            SIGNATURE_FIELD_NUMBER: _ClassVar[int]
            mode: SignMode
            signature: bytes

            def __init__(self, mode: _Optional[_Union[(SignMode, str)]]=..., signature: _Optional[bytes]=...) -> None:
                ...
        MULTI_FIELD_NUMBER: _ClassVar[int]
        SINGLE_FIELD_NUMBER: _ClassVar[int]
        multi: SignatureDescriptor.Data.Multi
        single: SignatureDescriptor.Data.Single

        def __init__(self, single: _Optional[_Union[(SignatureDescriptor.Data.Single, _Mapping)]]=..., multi: _Optional[_Union[(SignatureDescriptor.Data.Multi, _Mapping)]]=...) -> None:
            ...
    DATA_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    data: SignatureDescriptor.Data
    public_key: _any_pb2.Any
    sequence: int

    def __init__(self, public_key: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., data: _Optional[_Union[(SignatureDescriptor.Data, _Mapping)]]=..., sequence: _Optional[int]=...) -> None:
        ...

class SignatureDescriptors(_message.Message):
    __slots__ = ['signatures']
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    signatures: _containers.RepeatedCompositeFieldContainer[SignatureDescriptor]

    def __init__(self, signatures: _Optional[_Iterable[_Union[(SignatureDescriptor, _Mapping)]]]=...) -> None:
        ...

class SignMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n sentinel/deposit/v1/events.proto\x12\x13sentinel.deposit.v1\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto"\x9b\x01\n\x08EventAdd\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12j\n\x05coins\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB@\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x0cyaml:"coins""\xa0\x01\n\rEventSubtract\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12j\n\x05coins\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB@\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x0cyaml:"coins"B:Z0github.com/sentinel-official/hub/x/deposit/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.deposit.v1.events_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z0github.com/sentinel-official/hub/x/deposit/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _EVENTADD.fields_by_name['address']._options = None
    _EVENTADD.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTADD.fields_by_name['coins']._options = None
    _EVENTADD.fields_by_name['coins']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x0cyaml:"coins"'
    _EVENTSUBTRACT.fields_by_name['address']._options = None
    _EVENTSUBTRACT.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTSUBTRACT.fields_by_name['coins']._options = None
    _EVENTSUBTRACT.fields_by_name['coins']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x0cyaml:"coins"'
    _EVENTADD._serialized_start = 112
    _EVENTADD._serialized_end = 267
    _EVENTSUBTRACT._serialized_start = 270
    _EVENTSUBTRACT._serialized_end = 430




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fcosmos/auth/v1beta1/query.proto\x12\x13cosmos.auth.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1ecosmos/auth/v1beta1/auth.proto\x1a\x19cosmos_proto/cosmos.proto"R\n\x14QueryAccountsRequest\x12:\n\npagination\x18\x01 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x8a\x01\n\x15QueryAccountsResponse\x124\n\x08accounts\x18\x01 \x03(\x0b2\x14.google.protobuf.AnyB\x0c\xca\xb4-\x08AccountI\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"0\n\x13QueryAccountRequest\x12\x0f\n\x07address\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"K\n\x14QueryAccountResponse\x123\n\x07account\x18\x01 \x01(\x0b2\x14.google.protobuf.AnyB\x0c\xca\xb4-\x08AccountI"\x14\n\x12QueryParamsRequest"H\n\x13QueryParamsResponse\x121\n\x06params\x18\x01 \x01(\x0b2\x1b.cosmos.auth.v1beta1.ParamsB\x04\xc8\xde\x1f\x002\xa7\x03\n\x05Query\x12\x88\x01\n\x08Accounts\x12).cosmos.auth.v1beta1.QueryAccountsRequest\x1a*.cosmos.auth.v1beta1.QueryAccountsResponse"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/auth/v1beta1/accounts\x12\x8f\x01\n\x07Account\x12(.cosmos.auth.v1beta1.QueryAccountRequest\x1a).cosmos.auth.v1beta1.QueryAccountResponse"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/auth/v1beta1/accounts/{address}\x12\x80\x01\n\x06Params\x12\'.cosmos.auth.v1beta1.QueryParamsRequest\x1a(.cosmos.auth.v1beta1.QueryParamsResponse"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/auth/v1beta1/paramsB+Z)github.com/cosmos/cosmos-sdk/x/auth/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/auth/types'
    _QUERYACCOUNTSRESPONSE.fields_by_name['accounts']._options = None
    _QUERYACCOUNTSRESPONSE.fields_by_name['accounts']._serialized_options = b'\xca\xb4-\x08AccountI'
    _QUERYACCOUNTREQUEST._options = None
    _QUERYACCOUNTREQUEST._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _QUERYACCOUNTRESPONSE.fields_by_name['account']._options = None
    _QUERYACCOUNTRESPONSE.fields_by_name['account']._serialized_options = b'\xca\xb4-\x08AccountI'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERY.methods_by_name['Accounts']._options = None
    _QUERY.methods_by_name['Accounts']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/auth/v1beta1/accounts'
    _QUERY.methods_by_name['Account']._options = None
    _QUERY.methods_by_name['Account']._serialized_options = b"\x82\xd3\xe4\x93\x02)\x12'/cosmos/auth/v1beta1/accounts/{address}"
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/auth/v1beta1/params'
    _QUERYACCOUNTSREQUEST._serialized_start = 238
    _QUERYACCOUNTSREQUEST._serialized_end = 320
    _QUERYACCOUNTSRESPONSE._serialized_start = 323
    _QUERYACCOUNTSRESPONSE._serialized_end = 461
    _QUERYACCOUNTREQUEST._serialized_start = 463
    _QUERYACCOUNTREQUEST._serialized_end = 511
    _QUERYACCOUNTRESPONSE._serialized_start = 513
    _QUERYACCOUNTRESPONSE._serialized_end = 588
    _QUERYPARAMSREQUEST._serialized_start = 590
    _QUERYPARAMSREQUEST._serialized_end = 610
    _QUERYPARAMSRESPONSE._serialized_start = 612
    _QUERYPARAMSRESPONSE._serialized_end = 684
    _QUERY._serialized_start = 687
    _QUERY._serialized_end = 1110




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/slashing/v1beta1/slashing.proto\x12\x17cosmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xb7\x02\n\x14ValidatorSigningInfo\x12\x0f\n\x07address\x18\x01 \x01(\t\x12-\n\x0cstart_height\x18\x02 \x01(\x03B\x17\xf2\xde\x1f\x13yaml:"start_height"\x12-\n\x0cindex_offset\x18\x03 \x01(\x03B\x17\xf2\xde\x1f\x13yaml:"index_offset"\x12Q\n\x0cjailed_until\x18\x04 \x01(\x0b2\x1a.google.protobuf.TimestampB\x1f\xf2\xde\x1f\x13yaml:"jailed_until"\x90\xdf\x1f\x01\xc8\xde\x1f\x00\x12\x12\n\ntombstoned\x18\x05 \x01(\x08\x12?\n\x15missed_blocks_counter\x18\x06 \x01(\x03B \xf2\xde\x1f\x1cyaml:"missed_blocks_counter":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00"\x88\x04\n\x06Params\x12=\n\x14signed_blocks_window\x18\x01 \x01(\x03B\x1f\xf2\xde\x1f\x1byaml:"signed_blocks_window"\x12m\n\x15min_signed_per_window\x18\x02 \x01(\x0cBN\xf2\xde\x1f\x1cyaml:"min_signed_per_window"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12d\n\x16downtime_jail_duration\x18\x03 \x01(\x0b2\x19.google.protobuf.DurationB)\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x1dyaml:"downtime_jail_duration"\x12w\n\x1aslash_fraction_double_sign\x18\x04 \x01(\x0cBS\xf2\xde\x1f!yaml:"slash_fraction_double_sign"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12q\n\x17slash_fraction_downtime\x18\x05 \x01(\x0cBP\xf2\xde\x1f\x1eyaml:"slash_fraction_downtime"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00B3Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.slashing_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01'
    _VALIDATORSIGNINGINFO.fields_by_name['start_height']._options = None
    _VALIDATORSIGNINGINFO.fields_by_name['start_height']._serialized_options = b'\xf2\xde\x1f\x13yaml:"start_height"'
    _VALIDATORSIGNINGINFO.fields_by_name['index_offset']._options = None
    _VALIDATORSIGNINGINFO.fields_by_name['index_offset']._serialized_options = b'\xf2\xde\x1f\x13yaml:"index_offset"'
    _VALIDATORSIGNINGINFO.fields_by_name['jailed_until']._options = None
    _VALIDATORSIGNINGINFO.fields_by_name['jailed_until']._serialized_options = b'\xf2\xde\x1f\x13yaml:"jailed_until"\x90\xdf\x1f\x01\xc8\xde\x1f\x00'
    _VALIDATORSIGNINGINFO.fields_by_name['missed_blocks_counter']._options = None
    _VALIDATORSIGNINGINFO.fields_by_name['missed_blocks_counter']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"missed_blocks_counter"'
    _VALIDATORSIGNINGINFO._options = None
    _VALIDATORSIGNINGINFO._serialized_options = b'\xe8\xa0\x1f\x01\x98\xa0\x1f\x00'
    _PARAMS.fields_by_name['signed_blocks_window']._options = None
    _PARAMS.fields_by_name['signed_blocks_window']._serialized_options = b'\xf2\xde\x1f\x1byaml:"signed_blocks_window"'
    _PARAMS.fields_by_name['min_signed_per_window']._options = None
    _PARAMS.fields_by_name['min_signed_per_window']._serialized_options = b'\xf2\xde\x1f\x1cyaml:"min_signed_per_window"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['downtime_jail_duration']._options = None
    _PARAMS.fields_by_name['downtime_jail_duration']._serialized_options = b'\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x1dyaml:"downtime_jail_duration"'
    _PARAMS.fields_by_name['slash_fraction_double_sign']._options = None
    _PARAMS.fields_by_name['slash_fraction_double_sign']._serialized_options = b'\xf2\xde\x1f!yaml:"slash_fraction_double_sign"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _PARAMS.fields_by_name['slash_fraction_downtime']._options = None
    _PARAMS.fields_by_name['slash_fraction_downtime']._serialized_options = b'\xf2\xde\x1f\x1eyaml:"slash_fraction_downtime"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00'
    _VALIDATORSIGNINGINFO._serialized_start = 155
    _VALIDATORSIGNINGINFO._serialized_end = 466
    _PARAMS._serialized_start = 469
    _PARAMS._serialized_end = 989
